@@ -1,5 +1,5 @@
 ## File Name: frm_linreg_density.R
-## File Version: 0.935
+## File Version: 0.957
 
 frm_linreg_density <- function(model, y, design_matrix=NULL, case=NULL,
 		X = NULL , offset = NULL )
@@ -22,12 +22,16 @@ frm_linreg_density <- function(model, y, design_matrix=NULL, case=NULL,
 		beta <- coef(model)
 		y_pred <- Xdes %*% beta + offset_values
 	}
+	
 	w <- model$weights
 	yr <- residuals(model)
 	if ( is.null(w) ){
 		w <- rep( 1 , length( yr ) )
 	}
-	y_sd <- TAM::weighted_sd( yr , w = w )  
+
+	# y_sd <- TAM::weighted_sd( yr , w = w )  
+	y_sd <- mdmb_rcpp_weighted_sd_centered( x=yr, w=w )
+
 	y1 <- y
 	if ( length(y1) > length(w) ){
 		y1 <- y[ ! is.na(y) ]
@@ -35,14 +39,26 @@ frm_linreg_density <- function(model, y, design_matrix=NULL, case=NULL,
 			y1 <- y1[ seq(1,length(w))]
 		}
 	}
-	y_sd0 <- TAM::weighted_sd( y , w = w ) 
+	y <- y1
+	
+	# y_sd0 <- TAM::weighted_sd( x=y, w=w ) 
+	y_sd0 <- mdmb_rcpp_weighted_sd( x=y, w=w )
 	if ( ! is.null(model$sigma) ){	
 		y_sd <- model$sigma		
 	}
+
 	# R^2
 	R2 <- mean( 1 - y_sd^2 / y_sd0^2 )
-    d1 <- stats::dnorm( y , mean=y_pred , sd=y_sd )
-	d2 <- frm_normalize_posterior( post = d1 , case = case )		
+
+	#-- evaluate normal density
+	# d1 <- stats::dnorm( y , mean=y_pred , sd=y_sd )
+	d1 <- mdmb_rcpp_dnorm( x=y, mu=y_pred, sigma=y_sd)
+					
+	d2 <- frm_normalize_posterior( post = d1 , case = case )	
+	
+	#--- output
 	res <- list( "like" = d1 , "post" = d2 , "sigma" = y_sd , R2 = R2)	
 	return(res)
 }
+
+# z0 <- TAM:::tamcat(" ~~~~ mdmb_rcpp_dnorm",z0,TRUE)
